Documentation
¶
Index ¶
Constants ¶
const ( Reset = "\033[0m" Bold = "\033[1m" Dim = "\033[2m" Italic = "\033[3m" Under = "\033[4m" )
ANSI color codes
const ( Black = "\033[30m" Red = "\033[31m" Green = "\033[32m" Yellow = "\033[33m" Blue = "\033[34m" Magenta = "\033[35m" Cyan = "\033[36m" White = "\033[37m" )
Foreground colors
const ( BrightBlack = "\033[90m" BrightRed = "\033[91m" BrightGreen = "\033[92m" BrightYellow = "\033[93m" BrightBlue = "\033[94m" BrightMagenta = "\033[95m" BrightCyan = "\033[96m" BrightWhite = "\033[97m" )
Bright foreground colors
Variables ¶
This section is empty.
Functions ¶
func ColoredPrintf ¶
func ColoredPrintf(agentID, format string, args ...interface{})
ColoredPrintf prints formatted text with a colored agent prefix
func ColoredPrintln ¶
func ColoredPrintln(agentID, text string)
ColoredPrintln prints text with a colored agent prefix and newline
func FormatAgentPrefix ¶
FormatAgentPrefix formats the agent prefix with color
func GetAgentColor ¶
GetAgentColor returns a consistent color for the given agent ID
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.